@@ -31,7 +31,7 @@ use DateTime::TimeZone::Local::Unix;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -153,7 +153,7 @@ Pinto - Curate a repository of Perl modules
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -369,7 +369,7 @@ L<https://github.com/thaljef/Pinto>
 
 =head1 CONTRIBUTORS
 
-=for stopwords BenRifkah Bergsten-Buret Karen Etheridge Michael G. Schwern Jemmeson Mike Raynham Nikolay Martynov Oleg Gashev Steffen Schwigon Tommy Stanton Wolfgang Kinkeldei Yanick Champoux Boris Däppen brian d foy hesco popl Chris Kirke Cory G Watson David Steinbrunner Florian Ragwitz Glenn Fowler Jakob Voss Jeffrey Ryan Thalhammer Kahlil (Kal) Hodgson
+=for stopwords BenRifkah Bergsten-Buret Boris Däppen brian d foy Chris Kirke Cory G Watson David Steinbrunner Ferenc Erki Florian Ragwitz Glenn Fowler hesco Jakob Voss Jeffrey Ryan Thalhammer Kahlil (Kal) Hodgson Karen Etheridge Michael G. Schwern Jemmeson Mike Raynham Nikolay Martynov Oleg Gashev popl Steffen Schwigon Tommy Stanton Wolfgang Kinkeldei Yanick Champoux
 
 =over 4
 
@@ -379,6 +379,54 @@ BenRifkah Bergsten-Buret <mail.spammagnet+github@gmail.com>
 
 =item *
 
+Boris Däppen <bdaeppen.perl@gmail.com>
+
+=item *
+
+brian d foy <brian.d.foy@gmail.com>
+
+=item *
+
+Chris Kirke <chris.kirke@gmail.com>
+
+=item *
+
+Cory G Watson <gphat@onemogin.com>
+
+=item *
+
+David Steinbrunner <dsteinbrunner@pobox.com>
+
+=item *
+
+Ferenc Erki <erkiferenc@gmail.com>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Glenn Fowler <cebjyre@cpan.org>
+
+=item *
+
+hesco <hesco@campaignfoundations.com>
+
+=item *
+
+Jakob Voss <jakob@nichtich.de>
+
+=item *
+
+Jeffrey Ryan Thalhammer <jeff@thaljef.org>
+
+=item *
+
+Kahlil (Kal) Hodgson <kahlil.hodgson@dealmax.com.au>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
@@ -403,6 +451,10 @@ Oleg Gashev <oleg@gashev.net>
 
 =item *
 
+popl <popl_likes_to_code@yahoo.com>
+
+=item *
+
 Steffen Schwigon <ss5@renormalist.net>
 
 =item *
@@ -417,54 +469,6 @@ Wolfgang Kinkeldei <wolfgang@kinkeldei.de>
 
 Yanick Champoux <yanick@babyl.dyndns.org>
 
-=item *
-
-Boris Däppen <bdaeppen.perl@gmail.com>
-
-=item *
-
-brian d foy <brian.d.foy@gmail.com>
-
-=item *
-
-hesco <hesco@campaignfoundations.com>
-
-=item *
-
-popl <popl_likes_to_code@yahoo.com>
-
-=item *
-
-Chris Kirke <chris.kirke@gmail.com>
-
-=item *
-
-Cory G Watson <gphat@onemogin.com>
-
-=item *
-
-David Steinbrunner <dsteinbrunner@pobox.com>
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
-Glenn Fowler <cebjyre@cpan.org>
-
-=item *
-
-Jakob Voss <jakob@nichtich.de>
-
-=item *
-
-Jeffrey Ryan Thalhammer <jeff@thaljef.org>
-
-=item *
-
-Kahlil (Kal) Hodgson <kahlil.hodgson@dealmax.com.au>
-
 =back
 
 =head1 AUTHOR
