@@ -8,15 +8,15 @@ use MooseX::Types::Moose qw(Bool ArrayRef Str);
 use MooseX::MarkAsMethods ( autoclean => 1 );
 
 use Term::ANSIColor;
-use Term::EditorEdit;
 use File::Which qw(which);
 
+use Pinto::Editor;
 use Pinto::Types qw(Io ANSIColorPalette);
 use Pinto::Util qw(user_palette itis throw is_interactive);
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -177,7 +177,7 @@ sub edit {
     my $term = ( $^O eq 'MSWin32' ) ? 'CON' : '/dev/tty';
     open( STDIN, '<', $term ) or throw $!;
 
-    return Term::EditorEdit->edit( document => $document );
+    return Pinto::Editor->edit( document => $document );
 }
 
 #-----------------------------------------------------------------------------
@@ -260,7 +260,7 @@ Pinto::Chrome::Term - Interface for terminal-based interaction
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 AUTHOR
 
